@@ -19,8 +19,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 import six
 
-from blazar.db import api as db_api
-
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
@@ -66,12 +64,10 @@ class BasePlugin(object):
         """Reserve resource."""
         pass
 
+    @abc.abstractmethod
     def update_reservation(self, reservation_id, values):
         """Update reservation."""
-        reservation_values = {
-            'resource_id': values['resource_id']
-        }
-        db_api.reservation_update(reservation_id, reservation_values)
+        pass
 
     @abc.abstractmethod
     def on_end(self, resource_id):
@@ -91,9 +87,9 @@ class BasePlugin(object):
                           interval_end):
         """Heal reservations which suffer from resource failures.
 
-        :param: failed_resources: failed resources
-        :param: interval_begin: start date of the period to heal.
-        :param: interval_end: end date of the period to heal.
+        :param failed_resources: failed resources
+        :param interval_begin: start date of the period to heal.
+        :param interval_end: end date of the period to heal.
         :return: a dictionary of {reservation id: flags to update}
                  e.g. {'de27786d-bd96-46bb-8363-19c13b2c6657':
                        {'missing_resources': True}}
